#region MigraDoc - Creating Documents on the Fly
//
// Authors:
//   Klaus Potzesny (mailto:Klaus.Potzesny@pdfsharp.com)
//
// Copyright (c) 2001-2007 empira Software GmbH, Cologne (Germany)
//
// http://www.pdfsharp.com
// http://www.migradoc.com
// http://sourceforge.net/projects/pdfsharp
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
#endregion

using System;
using MigraDoc.DocumentObjectModel;

namespace MigraDoc.RtfRendering
{
  /// <summary>
  /// ListInfoRenderer (!!!uc!!!).
  /// </summary>
  internal class ListInfoRenderer : RendererBase
  {
    public ListInfoRenderer(DocumentObject domObj, RtfDocumentRenderer docRenderer) : base(domObj, docRenderer)
    {
      this.listInfo = domObj as ListInfo;
    }

    /// <summary>
    /// Renders a ListIfo to RTF.
    /// </summary>
    internal override void Render()
    {
      long templateID = 0;
      long listID = 0;
      Random rnd = new Random((int)System.DateTime.Now.Ticks);
      do
        templateID = (long)rnd.Next(int.MaxValue);
      while (idList.ContainsKey(templateID));
      do
        listID = (long)rnd.Next(int.MaxValue);
      while (idList.ContainsKey(listID));

      rtfWriter.WriteControl("list");
      rtfWriter.WriteControl("listtemplateid", templateID.ToString());
      rtfWriter.WriteControl("listsimple", 1);
      // Start
      Translate("ListType", "levelnfcn", RtfUnit.Undefined, "255", false);
      rtfWriter.WriteControl("leveljcn", 0);

      rtfWriter.WriteControl("levelstartat", 1); //Start-At muss immer vorhanden!?!?
      rtfWriter.WriteControl("levelold", 0); //Kompatibel mit Word 2000?

      rtfWriter.StartContent();
      rtfWriter.WriteControl("leveltext", " \\'01\\'00.");
      this.rtfWriter.WriteSeparator();
      rtfWriter.EndContent();

      rtfWriter.StartContent();
      rtfWriter.WriteControl("levelnumbers", " \\'01");
      this.rtfWriter.WriteSeparator();
      rtfWriter.EndContent();

      rtfWriter.WriteControl("levelfollow", 0);
      // End
      rtfWriter.WriteControl("listrestarthdn", 0);
      rtfWriter.WriteControl("listid", listID.ToString());
      rtfWriter.WriteControl("listname");
      rtfWriter.WriteText("List" + listID.ToString());
      this.rtfWriter.WriteSeparator();
    }

    private ListInfo listInfo;
    public static System.Collections.Hashtable idList = new System.Collections.Hashtable();
  }
}